==> mastercard_api_core-1.1.1-py2.py3-none-any.whl: mastercardapicore/core/config.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

"""
Config File for MasterCard APIs Core SDK
"""

from mastercardapicore.core import Constants

class Config(object):
    """
    Configurable options for MasterCard APIs Core SDK
    """

    sandbox         = True
    debug           = False
    authentication  = None

    def __init__(self):
        pass

    @classmethod
    def setDebug(cls,debug):
        cls.debug = debug

    @classmethod
    def isDebug(cls):
        return cls.debug

    @classmethod
    def setSandbox(cls,sandbox):
        cls.sandbox = sandbox

    @classmethod
    def isSandbox(cls):
        return cls.sandbox

    @classmethod
    def setAuthentication(cls,authentication):
        cls.authentication = authentication

    @classmethod
    def getAuthentication(cls):
        return cls.authentication

    @classmethod
    def getAPIBaseURL(cls):
        if cls.sandbox:
            return Constants.API_BASE_SANDBOX_URL
        else:
            return Constants.API_BASE_LIVE_URL

==> mastercard_api_core-1.2.0-py2.py3-none-any.whl: mastercardapicore/core/config.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

"""
Config File for MasterCard APIs Core SDK
"""

from mastercardapicore.core import Environment

class Config(object):
    """
    Configurable options for MasterCard APIs Core SDK
    """

    environment     = Environment.SANDBOX
    debug           = False
    authentication  = None
    registeredInstances = {}

    def __init__(self):
        pass

    @classmethod
    def setDebug(cls,debug):
        cls.debug = debug

    @classmethod
    def isDebug(cls):
        return cls.debug

    @classmethod
    def setSandbox(cls,sandbox):
        if sandbox :
            cls.environment = Environment.SANDBOX
        else:
            cls.environment =  Environment.PRODUCTION

    @classmethod
    def isSandbox(cls):
        return cls.environment == Environment.SANDBOX

    @classmethod
    def setAuthentication(cls,authentication):
        cls.authentication = authentication

    @classmethod
    def getAuthentication(cls):
        return cls.authentication

    @classmethod
    def setEnvironment(cls,environment):
        if environment:
            cls.environment = environment
            for registeredInstance in cls.registeredInstances.values():
                registeredInstance.setEnvironment(environment)
            
    @classmethod
    def getEnvironment(cls):
        return cls.environment    
    
    @classmethod
    def registerResourceConfig(cls,resourceConfig):
        className = resourceConfig.getName()
        if not className in cls.registeredInstances.keys():
            cls.registeredInstances[className] = resourceConfig

    @classmethod
    def clearResourceConfig(cls):
        cls.registeredInstances = {}
